<!-- This file is auto-generated. Do not edit it directly. -->

# Dopus

A lightweight tool-first framework for AI agent application development. Create an `Agent` class and decorate your tool functions with `@tool`. It just works.

Dopus is designed for building AI agents and their tools on top of existing LLM providers. In the spirit of being lightweight, it doesn't include any agents or tools out of the box.

## Getting Started

For more information on how to get started with Dopus, please refer to our [Getting Started](https://mashdevel.github.io/Dopus/guides/getting_started/) guide.

<!-- ## Contributing

We welcome contributions! Please see our [Contributing Guide](CONTRIBUTING.md) for more details on how to get started. -->

## License

Dopus is released under the MIT License. [Learn More](https://fossa.com/blog/open-source-licenses-101-mit-license/) details.